#
# spec file for package keyutils
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           keyutils
%define lname	libkeyutils1
Url:            http://people.redhat.com/~dhowells/keyutils/
Summary:        Linux Key Management Utilities
License:        GPL-2.0+ and LGPL-2.1+
Group:          System/Kernel
Version:        1.5.9
Release:        6.15
Source0:        http://people.redhat.com/~dhowells/keyutils/%name-%version.tar.bz2
Source1:        baselibs.conf
Patch1:         request-key-cifs.patch
Patch3:         request-key-nfs4.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Utilities to control the kernel key management facility and to provide
a mechanism by which the kernel can call back to user space to get a
key instantiated.

%package -n %lname
Summary:        Key utilities library
Group:          System/Kernel
Obsoletes:      keyutils-libs < %version-%release
Provides:       keyutils-libs = %version-%release

%description -n %lname
This package provides a wrapper library for the key management facility
system calls.

%package devel
Summary:        Development package for building linux key management utilities
Group:          System/Kernel
Requires:       %lname = %version
Requires:       glibc-devel

%description devel
This package provides headers and libraries for building key utilities.

%prep
%setup -q
%patch1 -p0
%patch3 -p1

%build
make %{?_smp_mflags} NO_ARLIB=1 CFLAGS="%{optflags}" CC="%__cc"

%install
make install NO_ARLIB=1 DESTDIR=%{buildroot} LIBDIR=/%{_lib} USRLIBDIR=%{_libdir}

%post -n %lname -p /sbin/ldconfig 

%postun -n %lname -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc README LICENCE.GPL
/sbin/*
/bin/*
%{_datadir}/keyutils
%{_mandir}/*/*
%config(noreplace) %{_sysconfdir}/request-key.conf
%dir %{_sysconfdir}/request-key.d/

%files -n %lname
%defattr(-,root,root,-)
%doc LICENCE.LGPL
/%{_lib}/libkeyutils.so.*

%files devel
%defattr(-,root,root,-)
%{_libdir}/libkeyutils.so
%{_includedir}/*

%changelog
* Thu Jun  5 2014 meissner@suse.com
- correct the obsoletes and provides in baselibs.conf to be correct.
  bnc#881533
* Wed May 14 2014 nfbrown@suse.com
- New upstream release 1.5.9.
  Particularly adds keyctl_invalidate, needed for latest nfs-utils.
  A few minor bugfixes and usability improvements.
* Mon Jul 29 2013 tchvatal@suse.com
- Use macros bit more and fix noreplace on folder, which is not
  good.
* Sun Jun 16 2013 lmuelle@suse.com
- Remove deprecated -c arg while calling cifs.upcall from request-key.conf.
* Fri Feb  1 2013 coolo@suse.com
- update license to new format
* Wed Jun 20 2012 meissner@suse.com
- various small improvements
- added a /etc/request-key.d/ snippet drop directory
* Mon Jun  4 2012 jeffm@suse.com
- Update nfs4 idmap support, nfs-client 1.2.6 changed parameters.
* Wed Apr 11 2012 jeffm@suse.com
- Add nfs4 idmap support
* Wed Oct  5 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Thu Sep 22 2011 meissner@suse.de
- Updated to 1.5.3
  - Fix unread variables.
  - Licence file update.
- Updated to 1.5
  - Disable RPATH setting in Makefile.
  - Add -I. to build to get this keyutils.h.
  - Make CFLAGS override on make command line work right.
  - Make specfile UTF-8.
  - Support KEYCTL_REJECT.
  - Support KEYCTL_INSTANTIATE_IOV.
  - Add AFSDB DNS lookup program from Wang Lei.
  - Generalise DNS lookup program.
  - Add recursive scan utility function.
  - Add bad key reap command to keyctl.
  - Add multi-unlink variant to keyctl unlink command.
  - Add multi key purger command to keyctl.
  - Handle multi-line commands in keyctl command table.
  - Move the package to version to 1.5.
- Update to 1.4-4
  - Make build guess at default libdirs and word size.
  - Make program build depend on library in Makefile.
  - Don't include $(DESTDIR) in MAN* macros.
  - Remove NO_GLIBC_KEYSYS as it is obsolete.
  - Have Makefile extract version info from specfile and version script.
  - Provide RPM build rule in Makefile.
  - Provide distclean rule in Makefile.
  - Fix local linking and RPATH.
  - Fix prototypes in manual pages (some char* should be void*).
  - Rename the keyctl_security.3 manpage to keyctl_get_security.3.
* Thu Sep 22 2011 jengelh@medozas.de
- Implement shlib package (libkeyutils1)
- Cleanup per Specfile Guidelines
* Tue Apr 19 2011 meissner@suse.de
- Upgraded to 1.4
  - Fix the library naming wrt the version.
  - Move the package to version to 1.4.
  - Fix spelling mistakes in manpages.
  - Add an index manpage for all the keyctl functions.
  - Fix rpmlint warnings.
- fixed parallel make
- do not include empty rpaths
* Thu Mar 18 2010 meissner@suse.de
- Upgraded to 1.3
  - Expose the kernel function to get a key's security context.
  - Expose the kernel function to set a processes keyring onto its parent.
  - Move libkeyutils library version to 1.3.
* Mon Dec 14 2009 jengelh@medozas.de
- add baselibs.conf as a source
- enable parallel building
* Mon Nov 24 2008 meissner@suse.de
- added 2 cifs helpers to request-key.conf (for CIFS DFS support)
  bnc#432494, FATE#303758
* Wed Nov 12 2008 crrodriguez@suse.de
- build request-key.c with -fno-strict-aliasing to avoid
  possible breakages
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Dec 14 2006 meissner@suse.de
- Upgraded to 1.2.
  - call ldconfig
  - removed manpages (now in global man-pages)
* Wed Jul 19 2006 meissner@suse.de
- Upgraded to 1.1.
  - cleanups, new manpage.
- no static lib anymore (like upstream).
* Fri Apr 21 2006 meissner@suse.de
- initial import of version 1.0.
